<?php

namespace Drupal\media_entity_remote_document\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\link\Plugin\Field\FieldFormatter\LinkFormatter;

/**
 * Remote document URL field formatter.
 *
 * @FieldFormatter(
 *   id = "remote_document_url_formatter",
 *   label = @Translation("Document with metatags"),
 *   description = @Translation("Display the remote document along with its associated metatags."),
 *   field_types = {
 *     "remote_document_url"
 *   }
 * )
 */
class RemoteDocumentUrlFormatter extends LinkFormatter {

  /**
   * {@inheritDoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = parent::viewElements($items, $langcode);
    $values = $items->getValue();

    foreach ($elements as $delta => $entity) {
      $url = $values[$delta]['uri'];
      $description = $values[$delta]['description'];
      $file_extension = pathinfo($url, PATHINFO_EXTENSION);
      $icon_url = $this->getIconUrl($file_extension);

      $elements[$delta] = [
        '#type' => 'markup',
        '#markup' => "<a href='{$url}' target='_blank'><img src='{$icon_url}' alt='{$file_extension} icon' class='document-icon'> {$description}</a>",
        '#allowed_tags' => ['a', 'img'],
      ];
    }

    return $elements;
  }

  /**
   * Get the icon URL based on the file extension.
   *
   * @param string $extension
   *   The file extension.
   *
   * @return string
   *   The URL of the icon.
   */
  private function getIconUrl(string $extension): string {
    return match (strtolower($extension)) {
      'pdf' => 'images/pdf.png',
      'doc', 'docx' => 'images/word.png',
      'xls', 'xlsx' => 'images/excel.png',
      default => 'images/file.png',
    };
  }

}
