<?php

namespace Drupal\media_entity_remote_document\Plugin\Field\FieldType;

use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\DataDefinition;
use Drupal\link\Plugin\Field\FieldType\LinkItem;

/**
 * Plugin implementation of the 'remote_document_url' field type.
 *
 * @FieldType(
 *   id = "remote_document_url",
 *   label = @Translation("Remote Document URL"),
 *   description = @Translation("This field is used to the URL of a remote document and its associated metadata."),
 *   category = @Translation("General"),
 *   default_widget = "remote_document_url_widget",
 *   default_formatter = "remote_document_url_formatter"
 * )
 */
class RemoteDocumentUrl extends LinkItem {

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition): array {
    $properties = parent::propertyDefinitions($field_definition);

    $properties['alt'] = DataDefinition::create('string')
      ->setLabel(t('Img alt text'));

    unset($properties['options']);

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition): array {
    $schema = parent::schema($field_definition);

    unset($schema['columns']['options']);

    $schema['columns']['alt'] = [
      'description' => 'The URI to be used for the Document SRC.',
      'type' => 'varchar',
      'length' => 255,
    ];

    return $schema;
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state): array {
    $element = parent::fieldSettingsForm($form, $form_state);
    $element['link_type']['#description'] = $this->t('In most cases this should be set to <i>External links only</i>.');
    $element['link_type']['#link_type'] = [
      '#default_value' => !empty($this->getSetting('link_type')) ? $this->getSetting('link_type') : static::LINK_EXTERNAL,
    ];

    return $element;
  }

}
