<?php

namespace Drupal\media_entity_remote_document\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\link\Plugin\Field\FieldWidget\LinkWidget;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Remote document URL field widget.
 *
 * @FieldWidget(
 *   id = "remote_document_url_widget",
 *   label = @Translation("Remote Document URL"),
 *   description = @Translation("A plaintext field for a remote document URL plus fields for metadata."),
 *   field_types = {
 *     "remote_document_url"
 *   }
 * )
 */
class RemoteDocumentUrlWidget extends LinkWidget {

  /**
   * The current route match.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  private RouteMatchInterface $routeMatch;

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): RemoteDocumentUrlWidget|WidgetBase|ContainerFactoryPluginInterface {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->routeMatch = $container->get('current_route_match');
    return $instance;
  }

  /**
   * {@inheritDoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state): array {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);

    unset($element['attributes']);

    $element['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title'),
      '#default_value' => $items[$delta]->description ?? NULL,
      '#maxlength' => 255,
      '#description' => $this->t('Title of the document.'),
      '#required' => FALSE,
    ];

    $element['description'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Description'),
      '#default_value' => $items[$delta]->description ?? NULL,
      '#maxlength' => 255,
      '#description' => $this->t('Short description of the document.'),
      '#required' => FALSE,
    ];

    $element['thumbnail'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Thumbnail'),
      '#default_value' => $items[$delta]->description ?? NULL,
      '#maxlength' => 255,
      '#description' => $this->t('Thumbnail of the document.'),
      '#required' => FALSE,
    ];

    return $element;
  }

}
